@@ -1,5 +1,6 @@
 import abc
 from past.builtins import long
+import subprocess
 
 import logging
 import requests
@@ -298,8 +299,10 @@ class LoadMaster(HttpClient):
             raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
 
     def backup(self):
-        response = self._get('/backup')
+        # Dirty API, dirty hack.
+        curl = ['curl', '-k', '{}/backup'.format(self.endpoint)]
         file_name = "{}.backup".format(self.ip_address)
-        with open(file_name, "wb") as backup_file:
-            backup_file.write(response)
-            return file_name
+        with open(file_name, 'wb') as file:
+            subprocess.call(curl, stdout=file)
+        return file_name
+
